FlashLock

Struct FlashLock 

pub struct FlashLock<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> { /* private fields */ }
flash lock

Implementations

Source

impl<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> FlashLock<'a, T, M, FLASH_SIZE>

custom method

pub fn new(flash: Flash<'a, T, M, FLASH_SIZE>) -> Self

create flash lock

pub fn build_flash_util( &'a self, offset: u32, erase_size: u32, ) -> FlashUtil<'a, T, M, FLASH_SIZE>

build flash util, more see FlashUtil::new

pub fn build_flash_util_default(&'a self) -> FlashUtil<'a, T, M, FLASH_SIZE>

build flash util default, more see FlashUtil::new_default

pub async fn capacity(&self) -> usize

Flash capacity. more see Flash::capacity

pub async fn blocking_jedec_id(&self) -> Result<u32, Error>

Read SPI flash JEDEC ID, more see Flash::blocking_jedec_id

pub async fn blocking_unique_id(&self, uid: &mut [u8]) -> Result<(), Error>

Read SPI flash unique ID, more see Flash::blocking_unique_id

pub async fn blocking_read( &self, offset: u32, bytes: &mut [u8], ) -> Result<(), Error>

Blocking read. more see Flash::blocking_read

pub async fn blocking_erase(&self, from: u32, to: u32) -> Result<(), Error>

Blocking erase. more see Flash::blocking_erase

pub async fn blocking_write( &self, offset: u32, bytes: &[u8], ) -> Result<(), Error>

Blocking write. more see Flash::blocking_write

pub async fn try_erase_write( &self, offset: u32, to: u32, buf: &[u8], ) -> Result<(), Error>

try erase and write, flash memory in areas [offset - to] will be erased
note that the area length of [offset - to] needs to meet the multiple relationship of the erase block size
such as rp2040 (to - offset) % 4096 must equal 0, because the minimum erase block size of rp2040 flash memory is 4096

Source

impl<'a, T: Instance, const FLASH_SIZE: usize> FlashLock<'a, T, Async, FLASH_SIZE>

custom method

pub async fn read(&self, offset: u32, bytes: &mut [u8]) -> Result<(), Error>

Async read. more see [Flash::<’a,T,Async,FLASH_SIZE>::read]