pub struct FlashUtil<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> {
pub flash: &'a FlashLock<'a, T, M, FLASH_SIZE>,
pub offset: u32,
/* private fields */
}Expand description
flash util
Fields
flash: &'a FlashLock<'a, T, M, FLASH_SIZE>flash device
offset: u32offset from the flash start, NOT an absolute address.
Implementations
Sourceimpl<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> FlashUtil<'a, T, M, FLASH_SIZE>
custom method
impl<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> FlashUtil<'a, T, M, FLASH_SIZE>
custom method
Sourcepub fn new(
flash: &'a FlashLock<'a, T, M, FLASH_SIZE>,
offset: u32,
erase_size: u32,
) -> Self
pub fn new( flash: &'a FlashLock<'a, T, M, FLASH_SIZE>, offset: u32, erase_size: u32, ) -> Self
create flash util
Sourcepub fn new_default(flash: &'a FlashLock<'a, T, M, FLASH_SIZE>) -> Self
pub fn new_default(flash: &'a FlashLock<'a, T, M, FLASH_SIZE>) -> Self
create flash util, default offset is 0x100000, default erase_size is 4096
Sourcepub async fn try_read(&self, buf: &mut [u8]) -> Result<(), Error>
pub async fn try_read(&self, buf: &mut [u8]) -> Result<(), Error>
try read to buf, more see FlashLock::blocking_read
Sourcepub async fn try_erase(&self, num: u32) -> Result<(), Error>
pub async fn try_erase(&self, num: u32) -> Result<(), Error>
try erase, more see FlashLock::blocking_erase
Sourcepub async fn try_erase_write(&self, buf: &[u8]) -> FlashResult<()>
pub async fn try_erase_write(&self, buf: &[u8]) -> FlashResult<()>
try erase and write data
flash memories with lengths multiple of erase_size will be automatically erased.
ff data is not empty, at least one flash memory of erase_size block will be erased
Sourcepub async fn erase_write(&self, buf: &[u8])
pub async fn erase_write(&self, buf: &[u8])
erase and write data, more see Self::try_erase_write
flash memories with lengths multiple of erase_size will be automatically erased.
ff data is not empty, at least one flash memory of erase_size block will be erased