pub struct FlashLock<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> { /* private fields */ }Expand description
flash lock
Implementations
Sourceimpl<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> FlashLock<'a, T, M, FLASH_SIZE>
custom method
impl<'a, T: Instance, M: Mode, const FLASH_SIZE: usize> FlashLock<'a, T, M, FLASH_SIZE>
custom method
Sourcepub fn build_flash_util(
&'a self,
offset: u32,
erase_size: u32,
) -> FlashUtil<'a, T, M, FLASH_SIZE>
pub fn build_flash_util( &'a self, offset: u32, erase_size: u32, ) -> FlashUtil<'a, T, M, FLASH_SIZE>
build flash util, more see FlashUtil::new
Sourcepub fn build_flash_util_default(&'a self) -> FlashUtil<'a, T, M, FLASH_SIZE>
pub fn build_flash_util_default(&'a self) -> FlashUtil<'a, T, M, FLASH_SIZE>
build flash util default, more see FlashUtil::new_default
Sourcepub async fn capacity(&self) -> usize
pub async fn capacity(&self) -> usize
Flash capacity. more see Flash::capacity
Sourcepub async fn blocking_jedec_id(&self) -> Result<u32, Error>
pub async fn blocking_jedec_id(&self) -> Result<u32, Error>
Read SPI flash JEDEC ID, more see Flash::blocking_jedec_id
Sourcepub async fn blocking_unique_id(&self, uid: &mut [u8]) -> Result<(), Error>
pub async fn blocking_unique_id(&self, uid: &mut [u8]) -> Result<(), Error>
Read SPI flash unique ID, more see Flash::blocking_unique_id
Sourcepub async fn blocking_read(
&self,
offset: u32,
bytes: &mut [u8],
) -> Result<(), Error>
pub async fn blocking_read( &self, offset: u32, bytes: &mut [u8], ) -> Result<(), Error>
Blocking read. more see Flash::blocking_read
Sourcepub async fn blocking_erase(&self, from: u32, to: u32) -> Result<(), Error>
pub async fn blocking_erase(&self, from: u32, to: u32) -> Result<(), Error>
Blocking erase. more see Flash::blocking_erase
Sourcepub async fn blocking_write(
&self,
offset: u32,
bytes: &[u8],
) -> Result<(), Error>
pub async fn blocking_write( &self, offset: u32, bytes: &[u8], ) -> Result<(), Error>
Blocking write. more see Flash::blocking_write
Sourcepub async fn try_erase_write(
&self,
offset: u32,
to: u32,
buf: &[u8],
) -> Result<(), Error>
pub async fn try_erase_write( &self, offset: u32, to: u32, buf: &[u8], ) -> Result<(), Error>
try erase and write, flash memory in areas [offset - to] will be erased
note that the area length of [offset - to] needs to meet the multiple relationship of the erase block size
such as rp2040 (to - offset) % 4096 must equal 0, because the minimum erase block size of rp2040 flash memory is 4096